@@ -9,7 +9,7 @@ import f61d.LOGO as LOGO
 from math import ceil
 from tqdm import *
 
-VERSION = (0,4,2)
+VERSION = (0,4,3)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -229,18 +229,19 @@ def crt(c_list,n_list):
         sm += a_i * invert(p, n_i) * p
     return int(sm % prod)
 
-def mtank(outPic,innerPic,output='tank.png'):
+def mtank(outerPic,innerPic,output='tank.png'):
     '''
         Mirage tank maker
         PIL is required
+        usage:mtank(outerIMG,innerIMG[,outputFile])
     '''
     from PIL import Image as img
     from f61d.tank import make
     if output.split('.')[-1] != 'png':
         print('')
-        raise
-    p1 = img.open(outPic)
+        raise 
+    p1 = img.open(outerPic)
     p1 = p1.convert('L')
     p2 = img.open(innerPic)
-    p2- = p2.convert('L')
+    p2 = p2.convert('L')
     make(p1,p2,output)
